@@ -2,7 +2,6 @@ package com.unciv.logic.multiplayer.storage
 
 import com.badlogic.gdx.Net
 import com.badlogic.gdx.utils.Base64Coder
-import com.unciv.ui.screens.savescreens.Gzip
 import com.unciv.utils.debug
 import kotlin.Exception
 
@@ -82,7 +81,7 @@ object UncivServerFileStorage : FileStorage {
             return false
 
         var setSuccessful = false
-        SimpleHttp.sendRequest(Net.HttpMethods.PUT, "$serverUrl/auth", content=Gzip.zip(newPassword), timeout=timeout, header=authHeader) {
+        SimpleHttp.sendRequest(Net.HttpMethods.PUT, "$serverUrl/auth", content=newPassword, timeout=timeout, header=authHeader) {
                 success, result, code ->
             if (!success) {
                 debug("Error from UncivServer during password set: %s", result)
