@@ -1,6 +1,7 @@
 package com.unciv.ui.popups.options
 
 import com.badlogic.gdx.scenes.scene2d.ui.Table
+import com.unciv.GUI
 import com.unciv.UncivGame
 import com.unciv.logic.files.UncivFiles
 import com.unciv.logic.files.MapSaver
@@ -13,16 +14,16 @@ import com.unciv.ui.components.extensions.onClick
 import com.unciv.ui.components.extensions.toCheckBox
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.extensions.toTextButton
+import com.unciv.utils.DebugUtils
 
 fun debugTab() = Table(BaseScreen.skin).apply {
     pad(10f)
     defaults().pad(5f)
     val game = UncivGame.Current
 
-    val worldScreen = game.worldScreen
-    if (worldScreen != null) {
+    if (GUI.isWorldLoaded()) {
         val simulateButton = "Simulate until turn:".toTextButton()
-        val simulateTextField = UncivTextField.create("Turn", game.simulateUntilTurnForDebug.toString())
+        val simulateTextField = UncivTextField.create("Turn", DebugUtils.SIMULATE_UNTIL_TURN.toString())
         val invalidInputLabel = "This is not a valid integer!".toLabel().also { it.isVisible = false }
         simulateButton.onClick {
             val simulateUntilTurns = simulateTextField.text.toIntOrNull()
@@ -30,20 +31,20 @@ fun debugTab() = Table(BaseScreen.skin).apply {
                 invalidInputLabel.isVisible = true
                 return@onClick
             }
-            game.simulateUntilTurnForDebug = simulateUntilTurns
+            DebugUtils.SIMULATE_UNTIL_TURN = simulateUntilTurns
             invalidInputLabel.isVisible = false
-            worldScreen.nextTurn()
+            GUI.getWorldScreen().nextTurn()
         }
         add(simulateButton)
         add(simulateTextField).row()
         add(invalidInputLabel).colspan(2).row()
     }
 
-    add("Supercharged".toCheckBox(game.superchargedForDebug) {
-        game.superchargedForDebug = it
+    add("Supercharged".toCheckBox(DebugUtils.SUPERCHARGED) {
+        DebugUtils.SUPERCHARGED = it
     }).colspan(2).row()
-    add("View entire map".toCheckBox(game.viewEntireMapForDebug) {
-        game.viewEntireMapForDebug = it
+    add("View entire map".toCheckBox(DebugUtils.VISIBLE_MAP) {
+        DebugUtils.VISIBLE_MAP = it
     }).colspan(2).row()
     val curGameInfo = game.gameInfo
     if (curGameInfo != null) {
@@ -89,7 +90,7 @@ fun debugTab() = Table(BaseScreen.skin).apply {
             }
         }
         curGameInfo.getCurrentPlayerCivilization().cache.updateSightAndResources()
-        if (worldScreen != null) worldScreen.shouldUpdate = true
+        GUI.setUpdateWorldOnNextRender()
     }
     add(unlockTechsButton).colspan(2).row()
 
@@ -107,7 +108,7 @@ fun debugTab() = Table(BaseScreen.skin).apply {
             tile.changeImprovement(resource.getImprovements().first())
         }
         curGameInfo.getCurrentPlayerCivilization().cache.updateSightAndResources()
-        if (worldScreen != null) worldScreen.shouldUpdate = true
+        GUI.setUpdateWorldOnNextRender()
     }
     add(giveResourcesButton).colspan(2).row()
 }
